#

##

##

##

##

##

##

###

###

##

##

##

    	NFT

    		apt install nftables
    		apt install inetutils-ping

    		apt install net-tools

    		systemctl start nftables

    		#.... journalctl --rotate;  journalctl --vacuum-time=0s;

    		http://172.17.0.1:20000

    	bridge networks
    		docker network ls
    		docker network create my_network

    	loopback connections

    	output ruleset
    		nft -j list ruleset

    	harbor
    		python3 -m http.server

    	docker start
    		sudo su

    		from image
    			docker image list

    			docker run --network host --privileged -v .:/goodest -it jumps:v2.1.0

    			docker run --privileged -v .:/goodest -p 20000:20000 -it jumps:v2.1.0
    			docker run -v .:/goodest -p 20000:20000 -it jumps:v2.1.0
    			docker exec -it 70b953975ca9 /bin/bash

    				docker run -v .:/rollercoaster -it --name ubuntu-rollercoaster ubuntu-network:v1

    		from container
    			docker container ls --all
    			f"docker restart { container_id }"
    			f"docker exec -it { container_id } /bin/bash"

    				#
    				#	docker restart cd55e3c71e0b;
    				#

    	check
    		nft -f filter.nft
    		nft list ruleset

    	user namespaces
    		#
    		#	block all except custom netwok namespace?
    		#

    		# apt update --fix-missing
    		apt install iproute2 -y
    		ip netns add tunnel_1; ip netns list

    		#
    		#	run user processes within a namespace?
    		#
    		ip netns exec tunnel_1 su - communicator

    	journals

    		didnt' work:
    			OUT_NOTE:IN= OUT=lo SRC=127.0.0.1 DST=127.0.0.1 LEN=60 TOS=0x00 PREC=0x00 TTL=64 ID=16692 DF PROTO=TCP SPT=39658 DPT=48938 WINDOW=65495 RES=0x00 SYN URGP=0

    		worked:
    			OUT_NOTE:IN= OUT=lo SRC=127.0.0.1 DST=127.0.0.1 LEN=60 TOS=0x00 PREC=0x00 TTL=64 ID=18775 DF PROTO=TCP SPT=38456 DPT=48938 WINDOW=65495 RES=0x00 SYN URGP=0

    		ID: ID of IP header.

    		SPT: port of source
    		DPT: port of destination